local L = AceLibrary("AceLocale-2.2"):new("Fence_Clicks")

-- Localization
L:RegisterTranslations("enUS", function() 
	return {
		["Clicks"] = true,
		["Click options"] = true,
		["Toggles %s click function."] = true,
		["Toggles Clicks module."] = true,
		["fill"] = true,
		["search"] = true,		
		["split"] = true,
		["trade"] = true		
	}
end)

L:RegisterTranslations("deDE", function()
	return {
		["Clicks"] = "Clicks",
		["Click options"] = "Click Optionen",
		["Toggles %s click function."] = "Schaltet %s Klickfunktion ein/aus.",
		["Toggles Clicks module."] = "Schaltet Clicks-Modul ein/aus.",
		["fill"] = "Ausf\195\188llen",
		["search"] = "Suchen",
		["split"] = "Teilen",
		["trade"] = "Trade"
	}
end)

Fence_Clicks = Fence:NewModule("Clicks")


	function Fence_Clicks:OnInitialize()
		self.db = Fence:AcquireDBNamespace("Clicks")
		if not self.db.profile.Fill then self.db.profile.Fill = true end
		if not self.db.profile.Search then self.db.profile.Search = true end
		if not self.db.profile.Split then self.db.profile.Split = true end
		if not self.db.profile.Trade then self.db.profile.Trade = true end
		
		Fence.options.args.clicks = {
			type = 'group',
			name = L["Clicks"],
			desc = L["Click options"],
				args = {
					toggle = {
						type = 'toggle',
						name = L["Clicks"],
						desc = L["Toggles Clicks module."],
						get = function() return Fence:IsModuleActive("Clicks") end,
						set = function(v) Fence:ToggleModuleActive("Clicks", v) end
					},
					fill = {
						type = 'toggle',
						name = L["fill"],
						desc = L["Toggles %s click function."], L["fill"],
						get = function() return self.db.profile.Fill end,
						set = function(v) self.db.profile.Fill = v end
					},
					search = {
						type = 'toggle',
						name = L["search"],
						desc = L["Toggles %s click function."], L["search"],
						get = function() return self.db.profile.Search end,
						set = function(v) self.db.profile.Search = v end
					},
					split = {
						type = 'toggle',
						name = L["split"],
						desc = L["Toggles %s click function."], L["split"],
						get = function() return self.db.profile.Split end,
						set = function(v) self.db.profile.Split = v end
					},
					trade = {
						type = 'toggle',
						name = L["trade"],
						desc = L["Toggles %s click function."], L["trade"],
						get = function() return self.db.profile.Trade end,
						set = function(v) self.db.profile.Trade = v end
					},
				}
		}
	end

	function Fence_Clicks:OnEnable()
		self:SecureHook("ContainerFrameItemButton_OnModifiedClick")
	end
	
	function Fence_Clicks:ContainerFrameItemButton_OnModifiedClick(...)
		local bag, item = this:GetParent():GetID(), this:GetID()
		if AuctionFrame and AuctionFrame:IsVisible() and not CursorHasItem() then
			if (...) == "LeftButton" and IsAltKeyDown() and GetContainerItemLink(bag, item) then
				PickupContainerItem(bag, item)
				ClickAuctionSellItemButton()
				StartAuction(MoneyInputFrame_GetCopper(StartPrice), MoneyInputFrame_GetCopper(BuyoutPrice), AuctionFrameAuctions.duration)
				if not AuctionFrameAuctions:IsVisible() then AuctionFrameTab3:Click() end
					return
			elseif (...) == "RightButton" then 
				if IsControlKeyDown() and self.db.profile.Search then self:AuctionSearch(GetContainerItemLink(bag, item))	end
				if IsAltKeyDown() and self.db.profile.Split then self:Splitter(1) end
				if IsShiftKeyDown() and self.db.profile.Split then self:Splitter(5) end
			end
		elseif TradeFrame:IsVisible() and (...) == "LeftButton" and IsAltKeyDown() and self.db.profile.Trade and not CursorHasItem() then
			PickupContainerItem(bag, item)
			local slot = TradeFrame_GetAvailableSlot()
			if slot then ClickTradeButton(slot) end
				return
		else
			if (...) == "RightButton" then 
				if IsAltKeyDown() and self.db.profile.Split then self:Splitter(1) end
				if IsShiftKeyDown() and self.db.profile.Split then self:Splitter(5) end
			end
		end
	end
	
	function Fence_Clicks:Splitter(amount)
		SplitContainerItem(this:GetParent():GetID(), this:GetID(), amount)
		for bag=0,4 do
			for slot=1, GetContainerNumSlots(bag) do
				if not GetContainerItemLink(bag, slot) then	PickupContainerItem(bag, slot) return end
			end
		end
	end

	function Fence_Clicks:AuctionSearch(link)
		if link and not strfind(link,"item:") then return end
		BrowseMinLevel:SetText('')
		BrowseMaxLevel:SetText('')
		UIDropDownMenu_SetText('',BrowseDropDown)
		UIDropDownMenu_SetSelectedName(BrowseDropDown)
		local name,il,ilv,ir,iml,class,sub
		if link then
			local i,j,name = strfind(link,"%[(.+)%]")
			BrowseName:SetText(name)
			BrowseName:HighlightText(0,-1)
			IsUsableCheckButton:SetChecked(false)
			local i,j,item = strfind(link,"(item:%d+:%d+:%d+:%d+)")
			name,il,ilv,ir,iml,class,sub = GetItemInfo(item)
		else
			BrowseName:SetText('')
			IsUsableCheckButton:SetChecked(true)
			class = 'Recipe'; sub = class
		end
		AuctionFrameBrowse.selectedClass = class
		for ix,name in ipairs(CLASS_FILTERS) do
			if name==class then
				AuctionFrameBrowse.selectedClassIndex = ix
				i = ix
				break
			end
		end
		if class~=sub then
			AuctionFrameBrowse.selectedSubclass = HIGHLIGHT_FONT_COLOR_CODE..sub..FONT_COLOR_CODE_CLOSE
				for ix,name in ipairs({GetAuctionItemSubClasses(i)}) do
					if name==sub then
						AuctionFrameBrowse.selectedSubclassIndex = ix
						break
					end
				end
		else
			AuctionFrameBrowse.selectedSubclass = nil
			AuctionFrameBrowse.selectedSubclassIndex = nil
		end
		AuctionFrameBrowse.selectedInvtype = nil
		AuctionFrameBrowse.selectedInvtypeIndex = nil
		AuctionFrameFilters_Update()
		BrowseSearchButton:Click()
		if not AuctionFrameBrowse:IsVisible() then AuctionFrameTab1:Click() end
	end
